@@ -289,12 +289,15 @@ grek_accented_ancient_small = {
     u"\u1FC3" : "e",  # Greek small letter eta with ypogegrammeni
     u"\u1FC4" : "e",  # Greek small letter eta with oxi and ypogegrammeni
     u"\u1FC6" : "e",  # Greek small letter eta with perispomeni
-    u"\u1FC7" : "e"  # Greek small letter eta with perispomeni and ypogegrammeni
+    u"\u1FC7" : "e",  # Greek small letter eta with perispomeni and ypogegrammeni
+    u"\u1FE6" : "u", # Greek small letter upsilon with perispomeni
+    u"\u1FE7" : "u" # Greek small letter upsilon with dialytika and perispomeni
 }
 
+# legal punctuation (for lacunae)
 legal_punctuation = {
     u"(" : "(",
-    u")" : ")",
+    u")" : ")", 
     u"." : "."
 }
 
@@ -308,9 +311,11 @@ def validate(value, allow):
     # truly valid (ranges are sparsely populated)
     
         cval = ord(c)
-        if cval in range(880, 1023) or cval in range(7936, 8191):
+        if cval in range(880, 1024) or cval in range(7936, 8192) or c == u' ':
             b = None
-            if 'small' in allow or 'mixed' in allow or 'all' in allow:
+            if c == u' ':
+                b = c
+            if not(b) and ('small' in allow or 'mixed' in allow or 'all' in allow):
                 try:
                     b = grek_unaccented_small[c]
                 except:
